Module: Fudge
- Defined in:
- lib/dicebag/systems/fudge.rb
Overview
This handles Fudge RPG type of rolls.
This probably isn’t (it totally isn’t!) the most effecient way to do this, but shows how to examine DiceBag objects to get what you need for wonky dice systems.
Defined Under Namespace
Classes: Roll
Constant Summary collapse
- DF =
Roll.new
Class Method Summary collapse
Class Method Details
.roll(num = 4) ⇒ Object
77 78 79 |
# File 'lib/dicebag/systems/fudge.rb', line 77 def self.roll(num = 4) Roll.new(num).roll end |